#ifndef _Constants_H
#define _Constants_H

// for debugging we can include code, but makes computation slower
// #define DEBUG 1

// dimension of model 0=finite 1=chain ... 3=3D (slow)
// lower values reduce computation effort in the inner loops
#define Dimension 2

// int Array[const int x=5] works only for C++
#define MAX_UNIT_CELL 4  // CaVO, kagome etc.
// #define MAX_UNIT_CELL 1  // speedup for Bravais lattices
#define MAX_NUM_SYM  16  // max= ... for ...

// size of the descriptor index, smaller is faster
//   examples 1D=3, 2D=7, 3Dm2=19 3Dm4=23, pre060611=60
#define MAX_SPIN_LIST 58   // configTables[block_size*MAX_SPIN_LIST]
//#define MAX_SPIN_LIST 1   // minimum for most speedup

// store config as 2bit (2s=1) per site (16sites/int*MAX_SPIN_LIST)
// or (ToDo) max-n flips * (x,y,z,uc) * char..short

// MAX_NUM_CONFIGURATIONS.max=2^(32-8)=16e6 (see storage.C term compression!)
// MAX_NUM_CONFIGURATIONS < 2^15 (for best term compression of 50%)
#define MAX_NUM_CONFIGURATIONS 36000
// v0902 static memory: 3*MAX_NUM_CONFIGURATIONS*MAX_SPIN_LIST*int
// v0903 temporary needs above size to alloc, than realloc to needed size

#define MAX_NUM_NEIGHBOURS 10

// int BTarray[MAX_LSUB+1][MAX_LSUB+1][MAX_LSUB+1] for (z,y,x) to idx
//  may consume unneccessary lot of memory
//  ToDo: remove and replace by dynamic allocations
#define MAX_LSUBM 30  // max distance and max flips (ToDo: add SUBN)

#define MAX_NUM_ITERATIONS 5000  // Mar08: reduced from 10000 to 4000
#define TOLERANCE 1e-10  // old= 1e-12 to strong? (double_prec=1e-13)
//#define TOLERANCE 1e-12  // old= 1e-12 to strong? (double_prec=1e-13)

/* momentum of convergence for direct iteration
 * next vector is a mixture of momentum*oldX + (1-momentum)*newX
 * high momentum is more stable but slower
 * low  momentum is faster but probably dont converge */
#define momentum 0.625 /* old: 0.7 */

// if no FLAGS defined, define for serial computation now
#ifndef PARALLEL_FLAG      // old longer macro name (obsolete)
#ifdef CFG_MPI             // new short macro name
#define PARALLEL_FLAG CFG_MPI
#else
#define PARALLEL_FLAG 0
#endif
#endif

#ifndef CFG_MPI
#define CFG_MPI PARALLEL_FLAG
#endif

#if CFG_MPI != PARALLEL_FLAG
#error Macros _CFG_MPI and _PARALLEL_FLAG differ
#endif

#ifndef MPICH_IGNORE_CXX_SEEK  // go around mpich2 compile bug
#define MPICH_IGNORE_CXX_SEEK
#endif

#endif
